==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_fields/ALTERNATEUOMID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ALTERNATEUOMID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ALTERNATEUOMID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PARENTUOMID" type="{http://schemas.datastream.net/MP_fields}UOMID_Type"/>
 *         &lt;element name="ALTERNATEUOMCODE" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALTERNATEUOMID_Type", propOrder = {
    "parentuomid",
    "alternateuomcode"
})
public class ALTERNATEUOMID_Type {

    @XmlElement(name = "PARENTUOMID", required = true)
    protected UOMID_Type parentuomid;
    @XmlElement(name = "ALTERNATEUOMCODE", required = true)
    protected String alternateuomcode;

    /**
     * Obtient la valeur de la propriété parentuomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getPARENTUOMID() {
        return parentuomid;
    }

    /**
     * Définit la valeur de la propriété parentuomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setPARENTUOMID(UOMID_Type value) {
        this.parentuomid = value;
    }

    /**
     * Obtient la valeur de la propriété alternateuomcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALTERNATEUOMCODE() {
        return alternateuomcode;
    }

    /**
     * Définit la valeur de la propriété alternateuomcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALTERNATEUOMCODE(String value) {
        this.alternateuomcode = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/ALTERNATEUOMID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ALTERNATEUOMID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ALTERNATEUOMID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PARENTUOMID" type="{http://schemas.datastream.net/MP_fields}UOMID_Type"/>
 *         &lt;element name="ALTERNATEUOMCODE" type="{http://schemas.datastream.net/MP_fields}CODE30_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ALTERNATEUOMID_Type", propOrder = {
    "parentuomid",
    "alternateuomcode"
})
public class ALTERNATEUOMID_Type {

    @XmlElement(name = "PARENTUOMID", required = true)
    protected UOMID_Type parentuomid;
    @XmlElement(name = "ALTERNATEUOMCODE", required = true)
    protected String alternateuomcode;

    /**
     * Gets the value of the parentuomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getPARENTUOMID() {
        return parentuomid;
    }

    /**
     * Sets the value of the parentuomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setPARENTUOMID(UOMID_Type value) {
        this.parentuomid = value;
    }

    /**
     * Gets the value of the alternateuomcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALTERNATEUOMCODE() {
        return alternateuomcode;
    }

    /**
     * Sets the value of the alternateuomcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALTERNATEUOMCODE(String value) {
        this.alternateuomcode = value;
    }

}
